# Abstract blueprints
The blueprints present in this folder provide a set of common underlying blueprint infrastructure, but are incomplete in some form or other. They are not registered as blueprints because they aren't intended to be launched, but rather to be extended upon.